<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package kihon
 * @since 1.0.0
 */


/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function kihon_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// admin bar overlap fix class
	if ( is_admin_bar_showing() )
		$classes[] = 'wp-admin-is-logged-in';

	return $classes;
}
add_filter( 'body_class', 'kihon_body_classes' );

if ( version_compare( $GLOBALS['wp_version'], '4.1', '<' ) ) :
	/**
	 * Filters wp_title to print a neat <title> tag kihond on what is being viewed.
	 *
	 * @param string $title Default title text for current view.
	 * @param string $sep Optional separator.
	 * @return string The filtered title.
	 */
	function kihon_wp_title( $title, $sep ) {
		if ( is_feed() ) {
			return $title;
		}

		global $page, $paged;

		// Add the blog name
		$title .= get_bloginfo( 'name', 'display' );

		// Add the blog description for the home/front page.
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) ) {
			$title .= " $sep $site_description";
		}

		// Add a page number if necessary:
		if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
			$title .= " $sep " . sprintf( __( 'Страница %s', 'kihon' ), max( $paged, $page ) );
		}

		return $title;
	}
	add_filter( 'wp_title', 'kihon_wp_title', 10, 2 );

	/**
	 * Title shim for sites older than WordPress 4.1.
	 *
	 * @link https://make.wordpress.org/core/2014/10/29/title-tags-in-4-1/
	 * @todo Remove this function when WordPress 4.3 is released.
	 */
	function kihon_render_title() {
		?>
		<title><?php wp_title( '|', true, 'right' ); ?></title>
		<?php
	}
	add_action( 'wp_head', 'kihon_render_title' );
endif;


if ( ! function_exists( 'kihon_read_more_link' ) ) :
/**
 * Modify read more link.
 *
 * @since 1.0.0
 */
function kihon_read_more_link() {
	return '<a class="more-link" href="' . get_permalink() . '">' . __( 'Читать далее', 'kihon' ); '</a>';
}
add_filter( 'the_content_more_link', 'kihon_read_more_link' );
endif;


if ( ! function_exists( 'kihon_the_post_thumbnail' ) ) :
/**
 * Replaces WP the post thumbnail by automatically adding image size
 * according to page tempalte.
 *
 * @since 1.0.0
 */
function kihon_the_post_thumbnail() {
	$featured_thumbnail_size = '';

	if( is_page_template( 'templates/full-width-page.php' ) )
		$featured_thumbnail_size = 'featured-thumbnail-full-width';
	else
		$featured_thumbnail_size = 'featured-thumbnail';

	echo get_the_post_thumbnail( null, $featured_thumbnail_size );
}
endif;
